@@ -1106,6 +1106,7 @@ populate_window (HildonIMFcitxFKB *self)
   {
         priv->buttons[3][i] = gtk_button_new();
         gtk_button_set_focus_on_click(GTK_BUTTON(priv->buttons[3][i]),FALSE);
+        gtk_widget_set_size_request(priv->buttons[3][i], -1, BUTTON_HEIGHT+fix_height);
         g_signal_connect(G_OBJECT(priv->buttons[3][i]), "clicked", G_CALLBACK(text_button_clicked), self);
         gtk_box_pack_start(GTK_BOX(priv->buttons[3][2]), GTK_WIDGET(priv->buttons[3][i]), TRUE, TRUE, 0);
   }
@@ -1161,7 +1162,7 @@ populate_window (HildonIMFcitxFKB *self)
         labelchild = gtk_bin_get_child(GTK_BIN(priv->buttons[i][j]));
         gtk_widget_modify_font(GTK_WIDGET(labelchild),font);
         gtk_widget_set_size_request(GTK_WIDGET(priv->buttons[i][j]),button_width,BUTTON_HEIGHT+fix_height);
-        g_signal_connect(G_OBJECT(priv->buttons[i][j]), "pressed", G_CALLBACK(text_button_clicked), self);
+        g_signal_connect(G_OBJECT(priv->buttons[i][j]), "released", G_CALLBACK(text_button_clicked), self);
         gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(priv->buttons[i][j]), FALSE, FALSE, 0);
     }
     if (i == 2){
